==> aliyun-sdk-oss-2.5.0-sources.jar: com/aliyun/oss/model/GetBucketReplicationProgressRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.aliyun.oss.model;

/**
 * 获取复制进度请求。
 */
public class GetBucketReplicationProgressRequest extends GenericRequest {
    public GetBucketReplicationProgressRequest(String bucketName,
            String replicationRuleID) {
        super(bucketName);
        this.replicationRuleID = replicationRuleID;
    }

    public GetBucketReplicationProgressRequest(String bucketName) {
        super(bucketName);
    }

    public String getReplicationRuleID() {
        return replicationRuleID;
    }

    public void setReplicationRuleID(String replicationRuleID) {
        this.replicationRuleID = replicationRuleID;
    }
    
    public GetBucketReplicationProgressRequest withReplicationRuleID(String replicationRuleID) {
        setReplicationRuleID(replicationRuleID);
        return this;
    }

    private String replicationRuleID;
}

==> aliyun-sdk-oss-2.8.3-sources.jar: com/aliyun/oss/model/GetBucketReplicationProgressRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package com.aliyun.oss.model;

/**
 * This request class is used to get the bucket replication progress information from OSS.
 */
public class GetBucketReplicationProgressRequest extends GenericRequest {
    public GetBucketReplicationProgressRequest(String bucketName,
            String replicationRuleID) {
        super(bucketName);
        this.replicationRuleID = replicationRuleID;
    }

    public GetBucketReplicationProgressRequest(String bucketName) {
        super(bucketName);
    }

    public String getReplicationRuleID() {
        return replicationRuleID;
    }

    public void setReplicationRuleID(String replicationRuleID) {
        this.replicationRuleID = replicationRuleID;
    }
    
    public GetBucketReplicationProgressRequest withReplicationRuleID(String replicationRuleID) {
        setReplicationRuleID(replicationRuleID);
        return this;
    }

    private String replicationRuleID;
}
